@@ -27,6 +27,7 @@ import gettext
 import logging
 import os
 import sqlite3
+import sys
 
 # public objects
 __all__ = ['Country', 'Language', 'LanguageNotFound',
@@ -46,7 +47,17 @@ if hasattr(os.path, 'get_module_path'):
     if not os.path.isfile(os.path.join(__path__, 'locales.db')):
         __path__ = None
 if __path__ is None:
-    __path__ = os.path.abspath(os.path.realpath(os.path.dirname(__file__)))
+    frozen = getattr(sys, 'frozen', None)
+    if frozen in ('dll', 'console_exe', 'windows_exe'):
+        __path__ = os.path.abspath(os.path.dirname(sys.executable))
+    elif frozen == 'macosx_app':
+        __path__ = os.path.abspath(os.environ['RESOURCEPATH'])
+    elif frozen is True:
+        # Handle executables produced by PyInstaller.
+        __path__ = sys._MEIPASS
+    else:
+        __path__ = os.path.abspath(os.path.realpath(os.path.dirname(__file__)))
+    
 
 # loading the database
 _database = sqlite3.connect(os.path.join(__path__, 'locales.db'))
@@ -142,4 +153,4 @@ def code_to_name(code, separator='_'):
         country = Country.by_alpha_2(code[1]).translation
         return '{} ({})'.format(lang, country)
     else:
-        return Language.by_iso_639_1(code[0]).translation
\ No newline at end of file
+        return Language.by_iso_639_1(code[0]).translation
